# -*- coding: utf-8 -*-

"""Test Logos

Utilisation :
    créer les variables d'environnement: (indiquer les valeurs
    pour le serveur ScoDoc que vous voulez interroger)

    export SCODOC_URL="https://scodoc.xxx.net/"
    export SCODOC_USER="xxx"
    export SCODOC_PASSWD="xxx"
    export CHECK_CERTIFICATE=0 # ou 1 si serveur de production avec certif SSL valide

    (on peut aussi placer ces valeurs dans un fichier .env du répertoire tests/api).

    Lancer :
        pytest tests/api/test_api_departements.py
"""

import requests

from tests.api.setup_test_api import SCODOC_URL, CHECK_CERTIFICATE, HEADERS
from tests.api.tools_test_api import verify_fields

# departements
def test_departements():
    fields = [
        "id",
        "acronym",
        "description",
        "visible",
        "date_creation",
    ]

    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/departements",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    assert len(r.json()) == 1

    dept = r.json()[0]

    fields_OK = verify_fields(dept, fields)

    assert fields_OK is True


# liste_etudiants
def test_liste_etudiants():
    fields = [
        "civilite",
        "code_ine",
        "code_nip",
        "date_naissance",
        "email",
        "emailperso",
        "etudid",
        "nom",
        "prenom",
        "nomprenom",
        "lieu_naissance",
        "dept_naissance",
        "nationalite",
        "boursier",
        "id",
        "codepostaldomicile",
        "paysdomicile",
        "telephonemobile",
        "typeadresse",
        "domicile",
        "villedomicile",
        "telephone",
        "fax",
        "description",
    ]

    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/departements/TAPI/etudiants/liste",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )

    etu = r.json()[0]

    fields_OK = verify_fields(etu, fields)

    assert r.status_code == 200
    assert len(r.json()) == 16
    assert fields_OK is True

    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/departements/TAPI/etudiants/liste/1",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )

    etu = r.json()[0]

    fields_OK = verify_fields(etu, fields)

    assert r.status_code == 200
    assert len(r.json()) == 16
    assert fields_OK is True


# liste_semestres_courant
def test_semestres_courant():
    fields = [
        "titre",
        "gestion_semestrielle",
        "scodoc7_id",
        "date_debut",
        "bul_bgcolor",
        "date_fin",
        "resp_can_edit",
        "dept_id",
        "etat",
        "resp_can_change_ens",
        "id",
        "modalite",
        "ens_can_edit_eval",
        "formation_id",
        "gestion_compensation",
        "elt_sem_apo",
        "semestre_id",
        "bul_hide_xml",
        "elt_annee_apo",
        "block_moyennes",
        "formsemestre_id",
        "titre_num",
        "date_debut_iso",
        "date_fin_iso",
        "responsables",
    ]

    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/departements/TAPI/semestres_courants",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )

    sem = r.json()[0]

    fields_OK = verify_fields(sem, fields)

    assert r.status_code == 200
    assert len(r.json()) == 1
    assert fields_OK is True


# referenciel_competences
def test_referenciel_competences():
    r = requests.get(
        SCODOC_URL
        + "/ScoDoc/api/departements/TAPI/formations/1/referentiel_competences",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200 or 204
